@@ -70,6 +70,14 @@ class OptionArgument(object):
                         except ValueError as x:
 
                             raise InvalidIntegerException("the '%s' option's value '%s' cannot be interpreted as an integer" % (self.name, given_value))
+                    elif arg_spec.value_type == long:
+
+                        try:
+
+                            value       =   long(given_value)
+                        except ValueError as x:
+
+                            raise InvalidIntegerException("the '%s' option's value '%s' cannot be interpreted as a long integer" % (self.name, given_value))
                     elif arg_spec.value_type == str:
 
                         value   =   given_value
